@@ -356,7 +356,7 @@ internals.between = function (from, to) {
 internals.addMethod('between', internals.between);
 
 
-internals.above = function (value, delta) {
+internals.about = function (value, delta) {
 
     internals.assert(this, internals.type(this._ref) === 'number', 'Can only assert about on numbers');
     internals.assert(this, internals.type(value) === 'number' && internals.type(delta) === 'number', 'About assertion requires two number arguments');
@@ -364,7 +364,7 @@ internals.above = function (value, delta) {
     return this.assert(Math.abs(this._ref - value) <= delta, 'be about ' + value + ' \u00b1' + delta);
 };
 
-internals.addMethod('about', internals.above);
+internals.addMethod('about', internals.about);
 
 
 internals.instanceof = function (type) {
