@@ -143,7 +143,7 @@ describe('expect()', () => {
         }
 
         Code.settings.truncateMessages = origTruncate;
-        const message = exception.message.replace(/\n/g, '').replace(/ {2,}/g, ' ').replace(']', ' ]');
+        const message = exception.message.replace(/\n/g, '').replace(/ {2,}/g, ' ').replace(/8]/, '8 ]');
         Hoek.assert(message === 'Expected [ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18 ] to be a string but got \'array\'', exception);
     });
 
@@ -586,9 +586,9 @@ describe('expect()', () => {
 
             it('invalidates assertion (anonymous type)', () => {
 
-                const Custom = function () { };
-                Util.inherits(Custom, Error);
-                delete Custom.name; // Ensure that the type is anonymous
+                const Custom = class extends Error {
+                    static name = undefined; // Ensure that the type is anonymous
+                };
 
                 try {
                     Code.expect(error).to.be.an.error(Custom);
@@ -1003,6 +1003,7 @@ describe('expect()', () => {
                     Code.expect({ a: 1, b: 2, c: 3 }).to.part.include({ a: 1, d: 4 });
                     Code.expect({ a: 1, b: 2, c: 3 }).to.only.include({ a: 1, b: 2, c: 3 });
                     Code.expect({ a: [1], b: [2], c: [3] }).to.include({ a: [1], c: [3] });
+                    Code.expect({ a: 1, b: { c: 3, d: 4 } }).to.part.include({ b: { c: 3 } });
                 }
                 catch (err) {
                     var exception = err;
@@ -2369,6 +2370,31 @@ describe('expect()', () => {
             });
         });
     });
+
+    it('handles cases where thrownAt() cannot parse the error', () => {
+
+        const captureStackTrace = Error.captureStackTrace;
+
+        Error.captureStackTrace = (error) => {
+
+            error.stack = 5;
+        };
+
+        try {
+            Code.expect(1).to.equal(2);
+        }
+        catch (err) {
+            var exception = err;
+        }
+        finally {
+            Error.captureStackTrace = captureStackTrace;
+        }
+
+        Hoek.assert(exception);
+        Hoek.assert(exception.message === 'Expected 1 to equal specified value: 2', exception.message);
+        Hoek.assert(exception.at.filename === __filename);
+        Hoek.assert(exception.at.column === '18');
+    });
 });
 
 describe('fail', () => {
